@@ -37,7 +37,7 @@ pub(crate) fn build_cluster_descriptor(
                 input_split: task_instance.input_split.clone(),
                 daemon: task_instance.daemon,
                 thread_id: "".to_string(),
-                stopped: false,
+                terminated: false,
             };
             task_descriptors.push(task_descriptor);
         }
